@@ -13,7 +13,7 @@
 import abc
 import inspect
 
-import six
+import importlib_metadata
 from stevedore import extension
 
 from cliff import _argparse
@@ -28,26 +28,15 @@ def _get_distributions_by_modules():
     distribution name (the name used with pip and PyPI) do not
     always match. We want to report which distribution caused the
     command to be installed, so we need to look up the values.
-
     """
-    import pkg_resources
     global _dists_by_mods
     if _dists_by_mods is None:
-        results = {}
-        for dist in pkg_resources.working_set:
-            try:
-                mod_names = dist.get_metadata('top_level.txt').strip()
-            except Exception:
-                # Could not retrieve metadata. Either the file is not
-                # present or we cannot read it. Ignore the
-                # distribution.
-                pass
-            else:
-                # Distributions may include multiple top-level
-                # packages (see setuptools for an example).
-                for mod_name in mod_names.splitlines():
-                    results[mod_name] = dist.project_name
-        _dists_by_mods = results
+        # There can be multiple distribution in the case of namespace packages
+        # so we'll just grab the first one
+        _dists_by_mods = {
+            k: v[0] for k, v in
+            importlib_metadata.packages_distributions().items()
+        }
     return _dists_by_mods
 
 
@@ -60,8 +49,7 @@ def _get_distribution_for_module(module):
     return dist_name
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Command(object):
+class Command(object, metaclass=abc.ABCMeta):
     """Base class for command plugins.
 
     When the command is instantiated, it loads extensions from a
@@ -76,6 +64,7 @@ class Command(object):
     """
 
     deprecated = False
+    conflict_handler = 'ignore'
 
     _description = ''
     _epilog = None
@@ -158,7 +147,7 @@ class Command(object):
             epilog=self.get_epilog(),
             prog=prog_name,
             formatter_class=_argparse.SmartHelpFormatter,
-            conflict_handler='ignore',
+            conflict_handler=self.conflict_handler,
         )
         for hook in self._hooks:
             hook.obj.get_parser(parser)
